==> aliyun-python-sdk-sas-1.1.5.tar.gz: aliyun-python-sdk-sas-1.1.5/aliyunsdksas/request/v20181203/DescribeExposedInstanceListRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeExposedInstanceListRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeExposedInstanceList','sas')
		self.set_method('POST')

	def get_ExposurePort(self):
		return self.get_query_params().get('ExposurePort')

	def set_ExposurePort(self,ExposurePort):
		self.add_query_param('ExposurePort',ExposurePort)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_VulStatus(self):
		return self.get_query_params().get('VulStatus')

	def set_VulStatus(self,VulStatus):
		self.add_query_param('VulStatus',VulStatus)

	def get_ExposureIp(self):
		return self.get_query_params().get('ExposureIp')

	def set_ExposureIp(self,ExposureIp):
		self.add_query_param('ExposureIp',ExposureIp)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_CurrentPage(self):
		return self.get_query_params().get('CurrentPage')

	def set_CurrentPage(self,CurrentPage):
		self.add_query_param('CurrentPage',CurrentPage)

	def get_ExposureComponent(self):
		return self.get_query_params().get('ExposureComponent')

	def set_ExposureComponent(self,ExposureComponent):
		self.add_query_param('ExposureComponent',ExposureComponent)

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_InstanceName(self):
		return self.get_query_params().get('InstanceName')

	def set_InstanceName(self,InstanceName):
		self.add_query_param('InstanceName',InstanceName)

==> aliyun-python-sdk-sas-1.1.7.tar.gz: aliyun-python-sdk-sas-1.1.7/aliyunsdksas/request/v20181203/DescribeExposedInstanceListRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest

class DescribeExposedInstanceListRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'Sas', '2018-12-03', 'DescribeExposedInstanceList','sas')
		self.set_method('POST')

	def get_ExposurePort(self):
		return self.get_query_params().get('ExposurePort')

	def set_ExposurePort(self,ExposurePort):
		self.add_query_param('ExposurePort',ExposurePort)

	def get_PageSize(self):
		return self.get_query_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_query_param('PageSize',PageSize)

	def get_VulStatus(self):
		return self.get_query_params().get('VulStatus')

	def set_VulStatus(self,VulStatus):
		self.add_query_param('VulStatus',VulStatus)

	def get_ExposureIp(self):
		return self.get_query_params().get('ExposureIp')

	def set_ExposureIp(self,ExposureIp):
		self.add_query_param('ExposureIp',ExposureIp)

	def get_GroupId(self):
		return self.get_query_params().get('GroupId')

	def set_GroupId(self,GroupId):
		self.add_query_param('GroupId',GroupId)

	def get_CurrentPage(self):
		return self.get_query_params().get('CurrentPage')

	def set_CurrentPage(self,CurrentPage):
		self.add_query_param('CurrentPage',CurrentPage)

	def get_ExposureComponent(self):
		return self.get_query_params().get('ExposureComponent')

	def set_ExposureComponent(self,ExposureComponent):
		self.add_query_param('ExposureComponent',ExposureComponent)

	def get_InstanceId(self):
		return self.get_query_params().get('InstanceId')

	def set_InstanceId(self,InstanceId):
		self.add_query_param('InstanceId',InstanceId)

	def get_InstanceName(self):
		return self.get_query_params().get('InstanceName')

	def set_InstanceName(self,InstanceName):
		self.add_query_param('InstanceName',InstanceName)

	def get_HealthStatus(self):
		return self.get_query_params().get('HealthStatus')

	def set_HealthStatus(self,HealthStatus):
		self.add_query_param('HealthStatus',HealthStatus)
